@@ -1,7 +1,7 @@
 package Test::Script;
 
 # ABSTRACT: Basic cross-platform tests for scripts
-our $VERSION = '1.22_01'; # TRIAL VERSION
+our $VERSION = '1.24_01'; # TRIAL VERSION
 $VERSION = eval $VERSION;
 
 
@@ -148,7 +148,7 @@ sub script_runs {
   my $opt    = _options(\@_);
   my $unix   = shift @$args;
   my $path   = path( $unix );
-  my $pargs  = _perl_args($path);
+  my $pargs  = [ @{ _perl_args($path) }, @{ $opt->{interpreter_options} } ];
   my $dir    = _preload_module();
   my $cmd    = [ perl, @$pargs, "-I$dir", '-M__TEST_SCRIPT__', $path, @$args ];
   $stdout = '';
@@ -332,6 +332,19 @@ sub _options {
   $options{stdout} = \$stdout unless defined $options{stdout};
   $options{stderr} = \$stderr unless defined $options{stderr};
 
+  if(defined $options{interpreter_options})
+  {
+    unless(ref $options{interpreter_options} eq 'ARRAY')
+    {
+      require Text::ParseWords;
+      $options{interpreter_options} = [ Text::ParseWords::shellwords($options{interpreter_options}) ];
+    }
+  }
+  else
+  {
+    $options{interpreter_options} = [];
+  }
+
   \%options;
 }
 
@@ -362,7 +375,7 @@ Test::Script - Basic cross-platform tests for scripts
 
 =head1 VERSION
 
-version 1.22_01
+version 1.24_01
 
 =head1 SYNOPSIS
 
@@ -438,6 +451,12 @@ You may pass in options as a hash as the second argument.
 The expected exit value.  The default is to use whatever indicates success
 on your platform (usually 0).
 
+=item interpreter_options
+
+Array reference of Perl options to be passed to the interpreter.  Things
+like C<-w> or C<-x> can be passed this way.  This may be either a single
+string or an array reference.
+
 =item signal
 
 The expected signal.  The default is 0.  Use with care!  This may not be
